@@ -3,13 +3,14 @@ from aliyunsdkcore.client import AcsClient
 from aliyunsdksts.request.v20150401.AssumeRoleRequest import AssumeRoleRequest
 import json
 from .base import Aliyun
-from pydantic import BaseModel, Field
-
+from pydantic import BaseModel
+from ..pydantic import PydanticModelConfig
 
 class AliyunStsToken(BaseModel):
-    access_key_secret: str = Field(..., validation_alias="AccessKeySecret", serialization_alias="accessKeySecret")
-    security_token: str = Field(..., validation_alias="SecurityToken", serialization_alias="securityToken")
-    access_key_id: str = Field(..., validation_alias="AccessKeyId", serialization_alias="accessKeyId")
+    model_config = PydanticModelConfig.default()
+    access_key_secret: str
+    security_token: str
+    access_key_id: str
 
 
 class AliyunSts(Aliyun):
@@ -35,7 +36,7 @@ class AliyunSts(Aliyun):
         response = client.do_action_with_exception(request)
         response_dict = json.loads(response.decode('utf-8'))['Credentials']
         return AliyunStsToken(
-            AccessKeySecret=response_dict['AccessKeySecret'],
-            SecurityToken=response_dict['SecurityToken'],
-            AccessKeyId=response_dict['AccessKeyId'],
+            access_key_secret=response_dict['AccessKeySecret'],
+            security_token=response_dict['SecurityToken'],
+            access_key_id=response_dict['AccessKeyId'],
         )
